@@ -3,10 +3,21 @@
 #' \code{save.ffdf} saves all ffdf data.frames in the given \code{dir}. Each column
 #' is stored as with filename <ffdfname>$<colname>.ff. All variables given in "..." are stored in ".RData" in the same directory.
 #' The data can be reloaded by starting a R session in the directory or by using \code{\link{load.ffdf}}.
+#' 
+#' Using \code{save.ffdf} automagically sets the \code{\link{finalizer}}s of the \code{ff}
+#' vectors to \code{"close"}. This means that the data will be preserved on disk when the 
+#' object is removed or the R sessions is closed. Data can be deleted either using
+#' \code{\link{delete}} or by removing the directory where the object were saved 
+#' (\code{dir}).
+#' @note
+#' When saving in the temporary directory pointed at by getOption("fftempdir"), \code{ff} assumes that the
+#' resulting files are to be deleted. Be sure to change the finalizers of the 
+#' ff vectors when saving in the temporary directory.
 #' @example ../examples/save_ffdf.R
 #' @param ... \code{ffdf} data.frames, \code{ff} vectors, or other variables to be saved in the directory
-#' @param dir path where .rdata file will be saved and all columns of supplied \code{ffdf}'s. It will be created if it doesn't exist.
-#' @param clone should the data.frame be cloned?
+#' @param dir path where .RData file will be saved and all columns of supplied \code{ffdf}'s. It will be created if it doesn't exist.
+#' @param clone should the ff vectors be \code{\link{clone}}'d, creating a snapshot of the supplied ffdf or ff objects?
+#' This should only be necessary if you still need the ff vectors in their current storage location.
 #' @param relativepath \code{logical} if \code{TRUE} the stored ff vectors will have relative paths, making moving the data to another storage a simple
 #' copy operation.
 #' @seealso \code{\link{load.ffdf}} 
@@ -23,13 +34,13 @@ save.ffdf <- function(..., dir="./ffdb", clone=FALSE, relativepath=TRUE){
    on.exit(setwd(oldwd))
    
    # TODO make this fail safe: when one of the 'n' is non-existing
-   existing <- sapply(names, exists, where=1)
+   existing <- sapply(names, exists, envir=parent.frame())
    names <- names[existing]
    if (any(!existing)){
      warning(names[!existing], " were not saved, because not found")
    }
    for (n in names){
-     x = get(n, pos=1)
+     x = get(n, envir=parent.frame())
      if (is.ffdf(x)) {
        if (isTRUE(clone)){
          x <- clone(x)
@@ -47,7 +58,7 @@ save.ffdf <- function(..., dir="./ffdb", clone=FALSE, relativepath=TRUE){
    
    if (relativepath && !clone){
      for (n in names){
-       x = get(n)
+       x = get(n, envir = parent.frame())
        if (is.ffdf(x)){
          for (i in physical(x)){
            filename(i) <- filename(i)
@@ -103,6 +114,9 @@ move.ffdf <- function(x, dir=".", name=as.character(substitute(x)), relativepath
 #' @seealso \code{\link{load.ffdf}} 
 #' @export
 load.ffdf <- function(dir, envir=parent.frame()){
+  if (!isTRUE(file.exists(dir))){
+    stop("directory '", dir ,"' does not exist")
+  }
   oldwd <- setwd(dir)
   on.exit(setwd(oldwd))
   
@@ -115,11 +129,11 @@ load.ffdf <- function(dir, envir=parent.frame()){
     x = get(n, envir=env)
     if (is.ffdf(x)){
       for (i in physical(x)){
-        filename(i) <- filename(i)
+        physical(i)$filename <- file_path_as_absolute(physical(i)$filename)
       }
       close(x)
     } else if (is.ff(x)){
-      filename(x) <- filename(x)
+      physical(x)$filename <- file_path_as_absolute(physical(x)$filename)
       close(x)
     }
     assign(n, x, envir=envir)
