@@ -1,19 +1,41 @@
+#' Cross Tabulation and Table Creation
+#' 
+#' Upgrades table to a generic function and implements a method 
+#' for ff vectors which works for ff factors.
+#' For other arguments passed on to table, uses \code{\link[base]{table}}\cr
+#'
 #' table.ff uses the cross-classifying factors to build a contingency table of 
 #' the counts at each combination of factor levels.\cr
 #' If \code{...} does not contain factors, \code{unique.ff} will add a levels 
 #' attribute to the non-factors.
-#'
-#' Details 
-#' @seealso \code{\link{table}}
-#' @export
+#' 
+#' @seealso \code{\link[base]{table}}
 #'
 #' @param ... \code{ff} factors or \code{ff} integers
-#' @param exclude see \code{\link{table}}
-#' @param useNA see \code{\link{table}}
-#' @param dnn see \code{\link{table}}
-#' @param deparse.level see \code{\link{table}}
-#'
-#' @return \code{table} object
+#' @param exclude see \code{\link[base]{table}}
+#' @param useNA see \code{\link[base]{table}}
+#' @param dnn see \code{\link[base]{table}}
+#' @param deparse.level see \code{\link[base]{table}}
+#' @usage table(..., exclude = if (useNA == "no") c(NA, NaN), useNA = c("no", "ifany", "always"), dnn = list.names(...), deparse.level = 1)
+#' @return \code{\link[base]{table}} object
+#' @export table
+table <- function( ...
+                 , exclude = if (useNA == "no") c(NA, NaN)
+                 , useNA = c("no","ifany", "always")
+                 , dnn = list.names(...)
+                 , deparse.level = 1
+){
+  UseMethod("table")
+}
+
+#' @S3method table default 
+table.default <- base::table
+
+#' @S3method table ff
+#' @export
+#' @usage table(..., exclude = if (useNA == "no") c(NA, NaN), useNA = c("no", "ifany", "always"), dnn = list.names(...), deparse.level = 1)
+#' @rdname table
+#' @aliases table
 table.ff <- function( ...
                      , exclude = if (useNA == "no") c(NA, NaN)
                      , useNA = c("no","ifany", "always")
@@ -42,7 +64,7 @@ table.ff <- function( ...
   
   for (i in chunk(dat)){
     Log$chunk(i)
-    factors <- as.list(dat[i,, drop=FALSE])
+    factors <- unname(as.list(dat[i,, drop=FALSE]))
     factors$exclude <- exclude
     factors$useNA <- useNA
     factors$deparse.level <- deparse.level
